0.1.7
-----

- `nb.load` and `nb.save` now support more file formats.
- Brain plotting now supports more spaces and species (`nb.plot`, `nb.plot_mebrains`).
- New `glm` module for simple GLM analysis and contrats.
- New `stats` module with various psychometrics functions.
- New benchmarking function for movie time point/segment classifications.
- New dataset, Life, from Nastase et al. (2017, 2018).
- More functions have docstrings now.
